##
##  dmalloc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         dmalloc
Summary:      Debug Memory Allocator Library
URL:          http://dmalloc.com/
Vendor:       Gray Watson
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Debugging
License:      GPL
Version:      5.6.5
Release:      20220606

#   list of sources
Source0:      http://dmalloc.com/releases/dmalloc-%{version}.tgz
Patch0:       dmalloc.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, texinfo, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The debug memory allocation (dmalloc) library has been designed as
    a drop in replacement for the system's malloc, realloc, calloc,
    free and other memory management routines while providing powerful
    debugging facilities configurable at runtime. These facilities
    include such things as memory-leak tracking, fence-post write
    detection, file/line number reporting, and general logging of
    statistics.

%track
    prog dmalloc = {
        version   = %{version}
        url       = http://dmalloc.com/releases/
        regex     = dmalloc-(\d+\.\d+(\.\d+)*)\.tgz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    TEXI2HTML="texi2any --html" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-threads \
        --disable-shlib
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install installdocs \
        prefix=$RPM_BUILD_ROOT%{l_prefix} \
        exec_prefix=$RPM_BUILD_ROOT%{l_prefix} \
        docdir=$RPM_BUILD_ROOT%{l_prefix}/share/dmalloc/doc
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/share/dmalloc
    %{l_shtool} install -c -m 644 \
        dmallocrc $RPM_BUILD_ROOT%{l_prefix}/share/dmalloc/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%doc %{l_prefix}/share/dmalloc/doc/*'

%files -f files

%clean

